@@ -28,7 +28,11 @@ pub struct ClientCapabilities {
   pub line_folding_only: bool,
 }
 
-#[derive(Debug, Clone, Deserialize)]
+fn is_true() -> bool {
+  true
+}
+
+#[derive(Debug, Clone, Deserialize, PartialEq, Eq)]
 #[serde(rename_all = "camelCase")]
 pub struct CodeLensSettings {
   /// Flag for providing implementation code lenses.
@@ -41,6 +45,10 @@ pub struct CodeLensSettings {
   /// an impact, the `references` flag needs to be `true`.
   #[serde(default)]
   pub references_all_functions: bool,
+  /// Flag for providing test code lens on `Deno.test` statements.  There is
+  /// also the `test_args` setting, but this is not used by the server.
+  #[serde(default = "is_true")]
+  pub test: bool,
 }
 
 impl Default for CodeLensSettings {
@@ -49,20 +57,36 @@ impl Default for CodeLensSettings {
       implementations: false,
       references: false,
       references_all_functions: false,
+      test: true,
     }
   }
 }
 
-#[derive(Debug, Clone, Deserialize)]
+#[derive(Debug, Clone, Deserialize, PartialEq, Eq)]
+#[serde(rename_all = "camelCase")]
+pub struct CodeLensSpecifierSettings {
+  /// Flag for providing test code lens on `Deno.test` statements.  There is
+  /// also the `test_args` setting, but this is not used by the server.
+  #[serde(default = "is_true")]
+  pub test: bool,
+}
+
+impl Default for CodeLensSpecifierSettings {
+  fn default() -> Self {
+    Self { test: true }
+  }
+}
+
+#[derive(Debug, Clone, Deserialize, PartialEq, Eq)]
 #[serde(rename_all = "camelCase")]
 pub struct CompletionSettings {
   #[serde(default)]
   pub complete_function_calls: bool,
-  #[serde(default)]
+  #[serde(default = "is_true")]
   pub names: bool,
-  #[serde(default)]
+  #[serde(default = "is_true")]
   pub paths: bool,
-  #[serde(default)]
+  #[serde(default = "is_true")]
   pub auto_imports: bool,
   #[serde(default)]
   pub imports: ImportCompletionSettings,
@@ -80,9 +104,15 @@ impl Default for CompletionSettings {
   }
 }
 
-#[derive(Debug, Clone, Deserialize)]
+#[derive(Debug, Clone, Deserialize, PartialEq, Eq)]
 #[serde(rename_all = "camelCase")]
 pub struct ImportCompletionSettings {
+  /// A flag that indicates if non-explicitly set origins should be checked for
+  /// supporting import suggestions.
+  #[serde(default = "is_true")]
+  pub auto_discover: bool,
+  /// A map of origins which have had explicitly set if import suggestions are
+  /// enabled.
   #[serde(default)]
   pub hosts: HashMap<String, bool>,
 }
@@ -90,6 +120,7 @@ pub struct ImportCompletionSettings {
 impl Default for ImportCompletionSettings {
   fn default() -> Self {
     Self {
+      auto_discover: true,
       hosts: HashMap::default(),
     }
   }
@@ -98,16 +129,21 @@ impl Default for ImportCompletionSettings {
 /// Deno language server specific settings that can be applied uniquely to a
 /// specifier.
 #[derive(Debug, Default, Clone, Deserialize)]
+#[serde(rename_all = "camelCase")]
 pub struct SpecifierSettings {
   /// A flag that indicates if Deno is enabled for this specifier or not.
   pub enable: bool,
+  /// Code lens specific settings for the resource.
+  #[serde(default)]
+  pub code_lens: CodeLensSpecifierSettings,
 }
 
 /// Deno language server specific settings that are applied to a workspace.
-#[derive(Debug, Default, Clone, Deserialize)]
+#[derive(Debug, Default, Clone, Deserialize, PartialEq, Eq)]
 #[serde(rename_all = "camelCase")]
 pub struct WorkspaceSettings {
   /// A flag that indicates if Deno is enabled for the workspace.
+  #[serde(default)]
   pub enable: bool,
 
   /// An option that points to a path string of the config file to apply to
@@ -165,8 +201,8 @@ impl ConfigSnapshot {
 }
 
 enum ConfigRequest {
+  All,
   Specifier(ModuleSpecifier, ModuleSpecifier),
-  Workspace,
 }
 
 #[derive(Debug, Default, Clone)]
@@ -197,12 +233,8 @@ impl Config {
         loop {
           match rx.recv().await {
             None => break,
-            Some(ConfigRequest::Workspace) => {
-              let mut items = vec![lsp::ConfigurationItem {
-                scope_uri: None,
-                section: Some(SETTINGS_SECTION.to_string()),
-              }];
-              let (specifier_uri_map, mut specifier_items): (
+            Some(ConfigRequest::All) => {
+              let (specifier_uri_map, items): (
                 Vec<(ModuleSpecifier, ModuleSpecifier)>,
                 Vec<lsp::ConfigurationItem>,
               ) = {
@@ -223,40 +255,18 @@ impl Config {
                     .collect(),
                 )
               };
-              items.append(&mut specifier_items);
               if let Ok(configs) = client.configuration(items).await {
                 let mut settings = settings_ref.write().unwrap();
                 for (i, value) in configs.into_iter().enumerate() {
-                  match i {
-                    0 => {
-                      match serde_json::from_value::<WorkspaceSettings>(value) {
-                        Ok(workspace_settings) => {
-                          settings.workspace = workspace_settings;
-                        }
-                        Err(err) => {
-                          error!(
-                            "Error converting workspace settings: {}",
-                            err
-                          );
-                        }
-                      }
+                  match serde_json::from_value::<SpecifierSettings>(value) {
+                    Ok(specifier_settings) => {
+                      let (specifier, uri) = specifier_uri_map[i].clone();
+                      settings
+                        .specifiers
+                        .insert(specifier, (uri, specifier_settings));
                     }
-                    _ => {
-                      match serde_json::from_value::<SpecifierSettings>(value) {
-                        Ok(specifier_settings) => {
-                          let (specifier, uri) =
-                            specifier_uri_map[i - 1].clone();
-                          settings
-                            .specifiers
-                            .insert(specifier, (uri, specifier_settings));
-                        }
-                        Err(err) => {
-                          error!(
-                            "Error converting specifier settings: {}",
-                            err
-                          );
-                        }
-                      }
+                    Err(err) => {
+                      error!("Error converting specifier settings: {}", err);
                     }
                   }
                 }
@@ -338,24 +348,32 @@ impl Config {
 
   pub fn specifier_enabled(&self, specifier: &ModuleSpecifier) -> bool {
     let settings = self.settings.read().unwrap();
-    if let Some(specifier_settings) = settings.specifiers.get(specifier) {
-      specifier_settings.1.enable
-    } else {
-      settings.workspace.enable
-    }
+    settings
+      .specifiers
+      .get(specifier)
+      .map(|(_, s)| s.enable)
+      .unwrap_or_else(|| settings.workspace.enable)
+  }
+
+  pub fn specifier_code_lens_test(&self, specifier: &ModuleSpecifier) -> bool {
+    let settings = self.settings.read().unwrap();
+    let value = settings
+      .specifiers
+      .get(specifier)
+      .map(|(_, s)| s.code_lens.test)
+      .unwrap_or_else(|| settings.workspace.code_lens.test);
+    value
   }
 
-  #[allow(clippy::redundant_closure_call)]
   pub fn update_capabilities(
     &mut self,
     capabilities: &lsp::ClientCapabilities,
   ) {
     if let Some(experimental) = &capabilities.experimental {
-      let get_bool =
-        |k: &str| experimental.get(k).and_then(|it| it.as_bool()) == Some(true);
-
-      self.client_capabilities.status_notification =
-        get_bool("statusNotification");
+      self.client_capabilities.status_notification = experimental
+        .get("statusNotification")
+        .and_then(|it| it.as_bool())
+        == Some(true)
     }
 
     if let Some(workspace) = &capabilities.workspace {
@@ -376,6 +394,16 @@ impl Config {
     }
   }
 
+  /// Update all currently cached specifier settings
+  pub async fn update_all_settings(&self) -> Result<(), AnyError> {
+    self
+      .tx
+      .send(ConfigRequest::All)
+      .await
+      .map_err(|_| anyhow!("Error sending config update task."))
+  }
+
+  /// Update a specific specifiers settings from the client.
   pub async fn update_specifier_settings(
     &self,
     specifier: &ModuleSpecifier,
@@ -387,14 +415,6 @@ impl Config {
       .await
       .map_err(|_| anyhow!("Error sending config update task."))
   }
-
-  pub async fn update_workspace_settings(&self) -> Result<(), AnyError> {
-    self
-      .tx
-      .send(ConfigRequest::Workspace)
-      .await
-      .map_err(|_| anyhow!("Error sending config update task."))
-  }
 }
 
 #[cfg(test)]
@@ -444,4 +464,39 @@ mod tests {
       .expect("could not update");
     assert!(config.specifier_enabled(&specifier));
   }
+
+  #[test]
+  fn test_set_workspace_settings_defaults() {
+    let config = setup();
+    config
+      .set_workspace_settings(json!({}))
+      .expect("could not update");
+    assert_eq!(
+      config.get_workspace_settings(),
+      WorkspaceSettings {
+        enable: false,
+        config: None,
+        import_map: None,
+        code_lens: CodeLensSettings {
+          implementations: false,
+          references: false,
+          references_all_functions: false,
+          test: true,
+        },
+        internal_debug: false,
+        lint: false,
+        suggest: CompletionSettings {
+          complete_function_calls: false,
+          names: true,
+          paths: true,
+          auto_imports: true,
+          imports: ImportCompletionSettings {
+            auto_discover: true,
+            hosts: HashMap::new(),
+          }
+        },
+        unstable: false,
+      }
+    );
+  }
 }
